@@ -16,25 +16,24 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef UI_H
 #define UI_H
 
 
-#include <config.h>
 #include "actions.h"
 #include "fr-stock.h"
 
 
 static GtkActionEntry action_entries[] = {
-	{ "ArchiveMenu", NULL, N_("_Archive") },
+	{ "FileMenu", NULL, N_("_Archive") },
 	{ "EditMenu", NULL, N_("_Edit") },
 	{ "ViewMenu", NULL, N_("_View") },
 	{ "HelpMenu", NULL, N_("_Help") },
 	{ "ArrangeFilesMenu", NULL, N_("_Arrange Files") },
+	/* Translators: this is the label for the "open recent file" sub-menu. */
 	{ "OpenRecentMenu", NULL, N_("Open _Recent") },
 
 	{ "About", GTK_STOCK_ABOUT,
@@ -56,7 +55,7 @@ static GtkActionEntry action_entries[] = {
 	{ "AddFolder_Toolbar", FR_STOCK_ADD_FOLDER,
 	  N_("Add Folder"), NULL,
 	  N_("Add a folder to the archive"),
-	  G_CALLBACK (activate_action_add_folder) },	  
+	  G_CALLBACK (activate_action_add_folder) },
 	{ "Close", GTK_STOCK_CLOSE,
 	  NULL, NULL,
 	  N_("Close the current archive"),
@@ -65,28 +64,28 @@ static GtkActionEntry action_entries[] = {
 	  N_("Contents"), "F1",
 	  N_("Display the File Roller Manual"),
 	  G_CALLBACK (activate_action_manual) },
-	  
+
 	{ "Copy", GTK_STOCK_COPY,
 	  NULL, NULL,
 	  N_("Copy the selection"),
 	  G_CALLBACK (activate_action_copy) },
 	{ "Cut", GTK_STOCK_CUT,
 	  NULL, NULL,
-	  N_("Cut the selection"),	  
+	  N_("Cut the selection"),
 	  G_CALLBACK (activate_action_cut) },
 	{ "Paste", GTK_STOCK_PASTE,
 	  NULL, NULL,
 	  N_("Paste the clipboard"),
-	  G_CALLBACK (activate_action_paste) },	 
+	  G_CALLBACK (activate_action_paste) },
 	{ "Rename", NULL,
 	  N_("_Rename..."), "F2",
 	  N_("Rename the selection"),
-	  G_CALLBACK (activate_action_rename) },	   
+	  G_CALLBACK (activate_action_rename) },
 	{ "Delete", GTK_STOCK_DELETE,
 	  NULL, "Delete",
 	  N_("Delete the selection from the archive"),
 	  G_CALLBACK (activate_action_delete) },
-	  
+
 	{ "CopyFolderFromSidebar", GTK_STOCK_COPY,
 	  NULL, NULL,
 	  N_("Copy the selection"),
@@ -98,16 +97,16 @@ static GtkActionEntry action_entries[] = {
 	{ "PasteFolderFromSidebar", GTK_STOCK_PASTE,
 	  NULL, NULL,
 	  N_("Paste the clipboard"),
-	  G_CALLBACK (activate_action_paste_folder_from_sidebar) },	 	
+	  G_CALLBACK (activate_action_paste_folder_from_sidebar) },
 	{ "RenameFolderFromSidebar", NULL,
 	  N_("_Rename..."), "F2",
 	  N_("Rename the selection"),
-	  G_CALLBACK (activate_action_rename_folder_from_sidebar) },	    
+	  G_CALLBACK (activate_action_rename_folder_from_sidebar) },
 	{ "DeleteFolderFromSidebar", GTK_STOCK_DELETE,
 	  NULL, NULL,
 	  N_("Delete the selection from the archive"),
 	  G_CALLBACK (activate_action_delete_folder_from_sidebar) },
-	  
+
 	{ "DeselectAll", NULL,
 	  N_("Dese_lect All"), "<shift><control>A",
 	  N_("Deselect all files"),
@@ -125,20 +124,20 @@ static GtkActionEntry action_entries[] = {
 	  N_("Extract files from the archive"),
 	  G_CALLBACK (activate_action_extract) },
 	{ "Find", GTK_STOCK_FIND,
-	  NULL, NULL,
+	  N_("Find..."), NULL,
 	  NULL,
 	  G_CALLBACK (activate_action_find) },
-	  
+
 	{ "LastOutput", NULL,
 	  N_("_Last Output"), NULL,
 	  N_("View the output produced by the last executed command"),
 	  G_CALLBACK (activate_action_last_output) },
 	{ "New", GTK_STOCK_NEW,
-	  NULL, NULL,
+	  N_("New..."), NULL,
 	  N_("Create a new archive"),
 	  G_CALLBACK (activate_action_new) },
 	{ "Open", GTK_STOCK_OPEN,
-	  NULL, NULL,
+	  N_("Open..."), NULL,
 	  N_("Open archive"),
 	  G_CALLBACK (activate_action_open) },
 	{ "Open_Toolbar", GTK_STOCK_OPEN,
@@ -162,7 +161,7 @@ static GtkActionEntry action_entries[] = {
 	  N_("Reload current archive"),
 	  G_CALLBACK (activate_action_reload) },
 	{ "SaveAs", GTK_STOCK_SAVE_AS,
-	  NULL, NULL,
+	  N_("Save As..."), NULL,
 	  N_("Save the current archive with a different name"),
 	  G_CALLBACK (activate_action_save_as) },
 	{ "SelectAll", GTK_STOCK_SELECT_ALL,
@@ -177,13 +176,13 @@ static GtkActionEntry action_entries[] = {
 	  N_("_Test Integrity"), NULL,
 	  N_("Test whether the archive contains errors"),
 	  G_CALLBACK (activate_action_test_archive) },
-	{ "ViewSelection", FR_STOCK_VIEW,
+	{ "ViewSelection", GTK_STOCK_OPEN,
 	  NULL, NULL,
-	  N_("View the selected file"),
+	  N_("Open the selected file"),
 	  G_CALLBACK (activate_action_view_or_open) },
-	{ "ViewSelection_Toolbar", FR_STOCK_VIEW,
+	{ "ViewSelection_Toolbar", GTK_STOCK_OPEN,
 	  NULL, NULL,
-	  N_("View the selected file"),
+	  N_("Open the selected file"),
 	  G_CALLBACK (activate_action_view_or_open) },
 	{ "OpenFolder", GTK_STOCK_OPEN,
 	  NULL, NULL,
@@ -193,7 +192,7 @@ static GtkActionEntry action_entries[] = {
 	  NULL, NULL,
 	  N_("Open the selected folder"),
 	  G_CALLBACK (activate_action_open_folder_from_sidebar) },
-	  
+
 	{ "GoBack", GTK_STOCK_GO_BACK,
 	  NULL, NULL,
 	  N_("Go to the previous visited location"),
@@ -208,6 +207,7 @@ static GtkActionEntry action_entries[] = {
 	  G_CALLBACK (activate_action_go_up) },
 	{ "GoHome", GTK_STOCK_HOME,
 	  NULL, NULL,
+	  /* Translators: the home location is the home folder. */
 	  N_("Go to the home location"),
 	  G_CALLBACK (activate_action_go_home) },
 };
@@ -218,22 +218,22 @@ static GtkToggleActionEntry action_toggle_entries[] = {
 	{ "ViewToolbar", NULL,
 	  N_("_Toolbar"), NULL,
 	  N_("View the main toolbar"),
-	  G_CALLBACK (activate_action_view_toolbar), 
+	  G_CALLBACK (activate_action_view_toolbar),
 	  TRUE },
 	{ "ViewStatusbar", NULL,
 	  N_("Stat_usbar"), NULL,
 	  N_("View the statusbar"),
-	  G_CALLBACK (activate_action_view_statusbar), 
+	  G_CALLBACK (activate_action_view_statusbar),
 	  TRUE },
 	{ "SortReverseOrder", NULL,
 	  N_("_Reversed Order"), NULL,
 	  N_("Reverse the list order"),
-	  G_CALLBACK (activate_action_sort_reverse_order), 
+	  G_CALLBACK (activate_action_sort_reverse_order),
 	  FALSE },
 	{ "ViewFolders", NULL,
 	  N_("_Folders"), "F9",
 	  N_("View the folders pane"),
-	  G_CALLBACK (activate_action_view_folders), 
+	  G_CALLBACK (activate_action_view_folders),
 	  FALSE },
 };
 static guint n_action_toggle_entries = G_N_ELEMENTS (action_toggle_entries);
@@ -261,19 +261,21 @@ static GtkRadioActionEntry sort_by_entries[] = {
 	  N_("by T_ype"), NULL,
 	  N_("Sort file list by type"), FR_WINDOW_SORT_BY_TYPE },
 	{ "SortByDate", NULL,
-	  N_("by _Date modified"), NULL,
+	  N_("by _Date Modified"), NULL,
 	  N_("Sort file list by modification time"), FR_WINDOW_SORT_BY_TIME },
 	{ "SortByLocation", NULL,
+	  /* Translators: this is the "sort by file location" menu item */
 	  N_("by _Location"), NULL,
+	  /* Translators: location is the file location */
 	  N_("Sort file list by location"), FR_WINDOW_SORT_BY_PATH },
 };
 static guint n_sort_by_entries = G_N_ELEMENTS (sort_by_entries);
 
 
-static const gchar *ui_info = 
+static const gchar *ui_info =
 "<ui>"
 "  <menubar name='MenuBar'>"
-"    <menu name='Archive' action='ArchiveMenu'>"
+"    <menu name='Archive' action='FileMenu'>"
 "      <menuitem action='New'/>"
 "      <menuitem action='Open'/>"
 "      <menu name='OpenRecentMenu' action='OpenRecentMenu'>"
@@ -311,7 +313,7 @@ static const gchar *ui_info =
 "      <menuitem action='ViewFolders'/>"
 "      <separator/>"
 "      <menuitem action='ViewAllFiles'/>"
-"      <menuitem action='ViewAsFolder'/>" 
+"      <menuitem action='ViewAsFolder'/>"
 /*"      <separator/>"
 "      <menu action='ArrangeFilesMenu'>"
 "        <menuitem action='SortByName'/>"
